# 欢迎使用 Quantum Algorithm (qalgo)

这是 Quantum Algorithm 项目的文档。本项目基于量子虚拟机实现了一些量子算法。

并且本项目还提供了大量用于组成量子算法的组件，例如量子逻辑门，量子算术运算，QRAM，量子态制备，量子傅里叶变换，量子测量等。

## 安装

### 系统需求

- 操作系统：Windows、Linux 或 macOS
- Python 版本：3.9 或以上，推荐3.10+

### 安装方式

```python
pip install qalgo
```

## 快速开始

```python
import qalgo

## TODO:

# 打印结果
print(result)
```

## 算法列表

### 已实现
- 线性求解器 (Quantum Linear System Solver)，基于离散绝热定理

### 待实现
- Shor算法
- 线性求解器 (Quantum Linear System Solver)，基于Quantum Walk
- 线性求解器 (Quantum Linear System Solver)，基于HHL算法
- 量子态制备


## 关于
本项目由 USTC-IAI 量子人工智能团队开发，主要成员为：

TODO.
